@@ -17,7 +17,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: jtag3_private.h 1208 2013-09-05 21:18:01Z joerg_wunsch $ */
+/* $Id: jtag3_private.h 1294 2014-03-12 23:03:18Z joerg_wunsch $ */
 
 
 /*
@@ -222,6 +222,47 @@
 #define XMEGA_ERASE_EEPROM_PAGE 0x06
 #define XMEGA_ERASE_USERSIG     0x07
 
+/* EDBG vendor commands */
+#define EDBG_VENDOR_AVR_CMD     0x80
+#define EDBG_VENDOR_AVR_RSP     0x81
+#define EDBG_VENDOR_AVR_EVT     0x82
+
+/* CMSIS-DAP commands */
+#define CMSISDAP_CMD_INFO       0x00 /* get info, followed by INFO byte */
+#  define CMSISDAP_INFO_VID         0x01 /* vendor ID (string) */
+#  define CMSISDAP_INFO_PID         0x02 /* product ID (string) */
+#  define CMSISDAP_INFO_SERIAL      0x03 /* serial number (string) */
+#  define CMSISDAP_INFO_FIRMWARE    0x04 /* firmware version (string) */
+#  define CMSISDAP_INFO_TARGET_VENDOR 0x05 /* target device vendor (string) */
+#  define CMSISDAP_INFO_TARGET_NAME   0x06 /* target device name (string) */
+#  define CMSISDAP_INFO_CAPABILITIES  0xF0 /* debug unit capabilities (byte) */
+#  define CMSISDAP_INFO_PACKET_COUNT  0xFE /* packet count (byte) (which packets, anyway?) */
+#  define CMSISDAP_INFO_PACKET_SIZE   0xFF /* packet size (short) */
+
+#define CMSISDAP_CMD_LED        0x01 /* LED control, followed by LED number and on/off byte */
+#  define CMSISDAP_LED_CONNECT      0x00 /* connect LED */
+#  define CMSISDAP_LED_RUNNING      0x01 /* running LED */
+
+#define CMSISDAP_CMD_CONNECT    0x02 /* connect to target, followed by DAP mode */
+#  define CMSISDAP_CONN_DEFAULT     0x00
+#  define CMSISDAP_CONN_SWD         0x01 /* serial wire debug */
+#  define CMSISDAP_CONN_JTAG        0x02 /* JTAG mode */
+
+#define CMSISDAP_CMD_DISCONNECT 0x03 /* disconnect from target */
+
+#define CMSISDAP_XFR_CONFIGURE  0x04 /* configure transfers; idle cycles (byte);
+                                        wait retry (short); match retry (short) */
+
+#define CMSISDAP_CMD_WRITEAPBORT 0x08 /* write to CoreSight ABORT register of target */
+
+#define CMSISDAP_CMD_DELAY      0x09 /* delay for number of microseconds (short) */
+
+#define CMSISDAP_CMD_RESET      0x0A /* reset target */
+
+#define CMSISDAP_CMD_SWJ_CLOCK  0x11 /* SWD/JTAG clock, (word) */
+
+#define CMSISDAP_CMD_SWD_CONFIGURE 0x13 /* configure SWD protocol; (byte) */
+
 #if !defined(JTAG3_PRIVATE_EXPORTED)
 
 struct mega_device_desc {
