@@ -13,11 +13,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: jtagmkI.h 722 2007-01-24 22:43:46Z joerg_wunsch $ */
+/* $Id: jtagmkI.h 1294 2014-03-12 23:03:18Z joerg_wunsch $ */
 
 #ifndef jtagmkI_h
 #define jtagmkI_h
@@ -26,6 +25,7 @@
 extern "C" {
 #endif
 
+extern const char jtagmkI_desc[];
 void jtagmkI_initpgm (PROGRAMMER * pgm);
 
 #ifdef __cplusplus
