@@ -13,11 +13,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: stk500.h 845 2009-10-10 01:41:40Z mludvig $ */
+/* $Id: stk500.h 1294 2014-03-12 23:03:18Z joerg_wunsch $ */
 
 #ifndef stk500_h
 #define stk500_h
@@ -26,6 +25,7 @@
 extern "C" {
 #endif
 
+extern const char stk500_desc[];
 void stk500_initpgm (PROGRAMMER * pgm);
 
 /* used by arduino.c to avoid duplicate code */
