@@ -13,15 +13,15 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: stk500generic.h 663 2006-09-19 22:27:30Z joerg_wunsch $ */
+/* $Id: stk500generic.h 1294 2014-03-12 23:03:18Z joerg_wunsch $ */
 
 #ifndef stk500generic_h__
 #define stk500generic_h__
 
+extern const char stk500generic_desc[];
 void stk500generic_initpgm (PROGRAMMER * pgm);
 
 #endif
