@@ -22,11 +22,6 @@
 
 #include "avrpart.h"
 
-// these are specifically assigned to USBtiny,
-// if you need your own VID and PIDs you can get them for cheap from
-// www.mecanique.co.uk so please don't reuse these. Thanks!
-#define USBTINY_VENDOR_DEFAULT  0x1781
-#define USBTINY_PRODUCT_DEFAULT 0x0C9F
 
 // Generic requests to the USBtiny
 #define	USBTINY_ECHO 	     0      // echo test
